//==============================================================================
//	File:      $URL: svn+ssh://repositorypub@repository.eecs.berkeley.edu/public/Projects/GateLib/branches/dev/Publications/Tutorials/Publications/EECS150/Labs/StructuralVerilog/Framework/BehavioralAccumulatorBitSlice.v $
//	Version:   $Revision: 26904 $
//	Author:    Chris Fletcher (http://cwfletcher.net)
//	Copyright: Copyright 2009-2010 UC Berkeley
//==============================================================================

//==============================================================================
//	Section:	License
//==============================================================================
//	Copyright (c) 2005-2010, Regents of the University of California
//	All rights reserved.
//
//	Redistribution and use in source and binary forms, with or without modification,
//	are permitted provided that the following conditions are met:
//
//		- Redistributions of source code must retain the above copyright notice,
//			this list of conditions and the following disclaimer.
//		- Redistributions in binary form must reproduce the above copyright
//			notice, this list of conditions and the following disclaimer
//			in the documentation and/or other materials provided with the
//			distribution.
//		- Neither the name of the University of California, Berkeley nor the
//			names of its contributors may be used to endorse or promote
//			products derived from this software without specific prior
//			written permission.
//
//	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
//	ANY EXPRESS OR InIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE InIMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
//	ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
//	ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//==============================================================================

//------------------------------------------------------------------------------
//	Module: 	AccumulatorBitSlice
//	Desc:    A 1-bit accumulator.  Specifically, this implementation 
//			'accumulates' by using an ALUBitSlice and stores its result 
//			in a 1-bit flip-flop, which for the purposes of the lab is a
//			Xilinx FDRSE primitive D flip-flop.
//	Inputs:  Clock: The clock signal.
//			ClockEnable: See FDRSE documentation.
//			Reset: ""
//			Set: ""
//			A: The first input.
//			CarryIn: The carry-in bit when the accumulator is set to add or subtract.
//			ALUOp: The ALUOp fed to the ALUBitSlice.
//	Output:	Result: The currently-accumulated running total.
//			CarryOut: The carry-out bit when the accumulator is set to add or subtract.
//
//	Author:  <a href="http://cwfletcher.net">Chris Fletcher</a>
//	Version: $Revision: 26904 $
//------------------------------------------------------------------------------
module BehavioralAccumulatorBitSlice(
			//------------------------------------------------------------------
			//	Flip-flop signals
			//------------------------------------------------------------------
			Clock,
			ClockEnable,
			Reset,
			Set,
			//------------------------------------------------------------------
			
			//------------------------------------------------------------------
			//	Input Interface
			//------------------------------------------------------------------
			A,
			CarryIn,
			ALUOp,
			//------------------------------------------------------------------
			
			//------------------------------------------------------------------
			//	Output Interface
			//------------------------------------------------------------------
			Result,
			CarryOut
			//------------------------------------------------------------------
	);
	//--------------------------------------------------------------------------
	//	Flip-flop Signal Inputs
	//--------------------------------------------------------------------------
	input wire										Clock, ClockEnable, Reset, Set;
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Inputs
	//--------------------------------------------------------------------------
	input wire										A, CarryIn;
	input wire		[2:0]							ALUOp;
	//--------------------------------------------------------------------------
	
	//--------------------------------------------------------------------------
	//	Outputs
	//--------------------------------------------------------------------------
	output wire										Result, CarryOut;
	//--------------------------------------------------------------------------

endmodule
//------------------------------------------------------------------------------